@@ -1,6 +1,6 @@
 package Devel::Declare::Lexer::Token;
 
-use v5.14.2;
+use v5;
 
 sub new
 {
