@@ -2,7 +2,7 @@ package Devel::Declare::Lexer::Token::LeftBracket;
 
 use base qw/ Devel::Declare::Lexer::Token /;
 
-use v5.14.2;
+use v5;
 
 sub new
 {
